/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/


#include <QtCore/QEventLoop>

#include <U2Core/Log.h>

#include "ForeverTask.h"

#define FOREVER_TASK_LOG_CAT "Forever task"

namespace U2 {

Logger log( FOREVER_TASK_LOG_CAT );

ForeverTask::ForeverTask() : Task( "Forever task", TaskFlag_None ) {
    log.trace( tr( "Forever task created" ) );
}

ForeverTask::~ForeverTask() {
}

void ForeverTask::run() {
    QEventLoop loop;
    loop.exec();
}

} // U2
